@@ -1,5 +1,5 @@
 setMethod("t", signature(x = "dtCMatrix"),
-          function(x) .Call("tsc_transpose", x),
+          function(x) .Call("tsc_transpose", x, PACKAGE = "Matrix"),
           valueClass = "dtCMatrix")
 
 setAs("dtCMatrix", "ltCMatrix",
@@ -20,7 +20,8 @@ setAs("dtCMatrix", "dgCMatrix",
       })
 
 setAs("dtCMatrix", "dgTMatrix",
-      function(from) .Call("tsc_to_dgTMatrix", from))
+      function(from)
+      .Call("tsc_to_dgTMatrix", from, PACKAGE = "Matrix"))
 
 setAs("dtCMatrix", "dgeMatrix",
       function(from) as(as(from, "dgTMatrix"), "dgeMatrix"))
