@@ -4,7 +4,8 @@
 ###             ============= ---> superclass methods in ./lsparseMatrix.R
 
 setAs("lgTMatrix", "lgCMatrix",
-      function(from) .Call("lgTMatrix_as_lgCMatrix", from))
+      function(from)
+      .Call("lgTMatrix_as_lgCMatrix", from, PACKAGE = "Matrix"))
 
 setAs("lgTMatrix", "matrix",
       function(from) as(as(from, "lgCMatrix"), "matrix"))
