@@ -16,16 +16,16 @@
 /*************************************************************************
 * This function performs k-way refinement
 **************************************************************************/
-void Random_KWayVolRefine(CtrlType *ctrl, GraphType *graph, int nparts, float *tpwgts, 
+void Random_KWayVolRefine(CtrlType *ctrl, GraphType *graph, int nparts, float *tpwgts,
                           float ubfactor, int npasses, int ffactor)
 {
   int i, ii, iii, j/* , jj */, k/* , kk, l, u */, pass, nvtxs,
-      nmoves, tvwgt, myndegrees, xgain; 
+      nmoves, tvwgt, myndegrees, xgain;
   int from/* , me */, to, oldcut, oldvol, vwgt;
   idxtype *xadj, *adjncy, *adjwgt;
   idxtype *where, *pwgts, *perm, *bndptr, *bndind, *minwgt, *maxwgt, *itpwgts, *updind, *marker, *phtable;
   VEDegreeType *myedegrees;
-  VRInfoType *myrinfo; 
+  VRInfoType *myrinfo;
 
   nvtxs = graph->nvtxs;
   xadj = graph->xadj;
@@ -37,7 +37,7 @@ void Random_KWayVolRefine(CtrlType *ctrl, GraphType *graph, int nparts, float *t
 
   where = graph->where;
   pwgts = graph->pwgts;
-  
+
   /* Setup the weight intervals of the various subdomains */
   minwgt =  idxwspacemalloc(ctrl, nparts);
   maxwgt = idxwspacemalloc(ctrl, nparts);
@@ -59,7 +59,7 @@ void Random_KWayVolRefine(CtrlType *ctrl, GraphType *graph, int nparts, float *t
 
   IFSET(ctrl->dbglvl, DBG_REFINE,
      printf("VolPart: [%5d %5d]-[%5d %5d], Balance: %3.2f, Nv-Nb[%5d %5d]. Cut: %5d, Vol: %5d\n",
-             pwgts[idxamin(nparts, pwgts)], pwgts[idxamax(nparts, pwgts)], minwgt[0], maxwgt[0], 
+             pwgts[idxamin(nparts, pwgts)], pwgts[idxamax(nparts, pwgts)], minwgt[0], maxwgt[0],
              1.0*nparts*pwgts[idxamax(nparts, pwgts)]/tvwgt, graph->nvtxs, graph->nbnd,
              graph->mincut, graph->minvol));
 
@@ -81,7 +81,7 @@ void Random_KWayVolRefine(CtrlType *ctrl, GraphType *graph, int nparts, float *t
         from = where[i];
         vwgt = graph->vwgt[i];
 
-        if (myrinfo->id > 0 && pwgts[from]-vwgt < minwgt[from]) 
+        if (myrinfo->id > 0 && pwgts[from]-vwgt < minwgt[from])
           continue;   /* This cannot be moved! */
 
         xgain = (myrinfo->id == 0 && myrinfo->ed > 0 ? graph->vsize[i] : 0);
@@ -91,7 +91,7 @@ void Random_KWayVolRefine(CtrlType *ctrl, GraphType *graph, int nparts, float *t
 
         for (k=0; k<myndegrees; k++) {
           to = myedegrees[k].pid;
-          if (pwgts[to]+vwgt <= maxwgt[to]+ffactor*myedegrees[k].gv && xgain+myedegrees[k].gv >= 0)  
+          if (pwgts[to]+vwgt <= maxwgt[to]+ffactor*myedegrees[k].gv && xgain+myedegrees[k].gv >= 0)
             break;
         }
         if (k == myndegrees)
@@ -119,16 +119,16 @@ void Random_KWayVolRefine(CtrlType *ctrl, GraphType *graph, int nparts, float *t
         }
         if (j == 0)
           continue;
-          
+
         /*=====================================================================
-        * If we got here, we can now move the vertex from 'from' to 'to' 
+        * If we got here, we can now move the vertex from 'from' to 'to'
         *======================================================================*/
         INC_DEC(pwgts[to], pwgts[from], vwgt);
         graph->mincut -= myedegrees[k].ed-myrinfo->id;
         graph->minvol -= (xgain+myedegrees[k].gv);
         where[i] = to;
 
-        IFSET(ctrl->dbglvl, DBG_MOVEINFO, printf("\t\tMoving %6d from %3d to %3d. Gain: [%4d %4d]. Cut: %6d, Vol: %6d\n", 
+        IFSET(ctrl->dbglvl, DBG_MOVEINFO, printf("\t\tMoving %6d from %3d to %3d. Gain: [%4d %4d]. Cut: %6d, Vol: %6d\n",
               i, from, to, xgain+myedegrees[k].gv, myedegrees[k].ed-myrinfo->id, graph->mincut, graph->minvol));
 
         KWayVolUpdate(ctrl, graph, i, from, to, marker, phtable, updind);
@@ -142,7 +142,7 @@ void Random_KWayVolRefine(CtrlType *ctrl, GraphType *graph, int nparts, float *t
     IFSET(ctrl->dbglvl, DBG_REFINE,
        printf("\t[%6d %6d], Balance: %5.3f, Nb: %6d. Nmoves: %5d, Cut: %6d, Vol: %6d\n",
                pwgts[idxamin(nparts, pwgts)], pwgts[idxamax(nparts, pwgts)],
-               1.0*nparts*pwgts[idxamax(nparts, pwgts)]/tvwgt, graph->nbnd, nmoves, graph->mincut, 
+               1.0*nparts*pwgts[idxamax(nparts, pwgts)]/tvwgt, graph->nbnd, nmoves, graph->mincut,
                graph->minvol));
 
     if (graph->minvol == oldvol && graph->mincut == oldcut)
@@ -161,17 +161,17 @@ void Random_KWayVolRefine(CtrlType *ctrl, GraphType *graph, int nparts, float *t
 /*************************************************************************
 * This function performs k-way refinement
 **************************************************************************/
-void Random_KWayVolRefineMConn(CtrlType *ctrl, GraphType *graph, int nparts, float *tpwgts, 
+void Random_KWayVolRefineMConn(CtrlType *ctrl, GraphType *graph, int nparts, float *tpwgts,
             float ubfactor, int npasses, int ffactor)
 {
   int i, ii, iii, j/* , jj */, k/* , kk */, l/* , u */, pass, nvtxs, nmoves,
-      tvwgt, myndegrees, xgain; 
+      tvwgt, myndegrees, xgain;
   int from, me, to, oldcut, oldvol, vwgt, nadd, maxndoms;
   idxtype *xadj, *adjncy, *adjwgt;
   idxtype *where, *pwgts, *perm, *bndptr, *bndind, *minwgt, *maxwgt, *itpwgts, *updind, *marker, *phtable;
   idxtype *pmat, *pmatptr, *ndoms;
   VEDegreeType *myedegrees;
-  VRInfoType *myrinfo; 
+  VRInfoType *myrinfo;
 
   nvtxs = graph->nvtxs;
   xadj = graph->xadj;
@@ -183,7 +183,7 @@ void Random_KWayVolRefineMConn(CtrlType *ctrl, GraphType *graph, int nparts, flo
 
   where = graph->where;
   pwgts = graph->pwgts;
-  
+
   /* Setup the weight intervals of the various subdomains */
   minwgt =  idxwspacemalloc(ctrl, nparts);
   maxwgt = idxwspacemalloc(ctrl, nparts);
@@ -210,7 +210,7 @@ void Random_KWayVolRefineMConn(CtrlType *ctrl, GraphType *graph, int nparts, flo
 
   IFSET(ctrl->dbglvl, DBG_REFINE,
      printf("VolPart: [%5d %5d]-[%5d %5d], Balance: %3.2f, Nv-Nb[%5d %5d]. Cut: %5d, Vol: %5d\n",
-             pwgts[idxamin(nparts, pwgts)], pwgts[idxamax(nparts, pwgts)], minwgt[0], maxwgt[0], 
+             pwgts[idxamin(nparts, pwgts)], pwgts[idxamax(nparts, pwgts)], minwgt[0], maxwgt[0],
              1.0*nparts*pwgts[idxamax(nparts, pwgts)]/tvwgt, graph->nvtxs, graph->nbnd,
              graph->mincut, graph->minvol));
 
@@ -234,7 +234,7 @@ void Random_KWayVolRefineMConn(CtrlType *ctrl, GraphType *graph, int nparts, flo
         from = where[i];
         vwgt = graph->vwgt[i];
 
-        if (myrinfo->id > 0 && pwgts[from]-vwgt < minwgt[from]) 
+        if (myrinfo->id > 0 && pwgts[from]-vwgt < minwgt[from])
           continue;   /* This cannot be moved! */
 
         xgain = (myrinfo->id == 0 && myrinfo->ed > 0 ? graph->vsize[i] : 0);
@@ -271,7 +271,7 @@ void Random_KWayVolRefineMConn(CtrlType *ctrl, GraphType *graph, int nparts, flo
           to = myedegrees[k].pid;
           if (!phtable[to])
             continue;
-          if (pwgts[to]+vwgt <= maxwgt[to]+ffactor*myedegrees[k].gv && xgain+myedegrees[k].gv >= 0)  
+          if (pwgts[to]+vwgt <= maxwgt[to]+ffactor*myedegrees[k].gv && xgain+myedegrees[k].gv >= 0)
             break;
         }
         if (k == myndegrees)
@@ -301,19 +301,19 @@ void Random_KWayVolRefineMConn(CtrlType *ctrl, GraphType *graph, int nparts, flo
         if (j == 0)
           continue;
 
-        for (j=0; j<myndegrees; j++) 
+        for (j=0; j<myndegrees; j++)
           phtable[myedegrees[j].pid] = -1;
 
-          
+
         /*=====================================================================
-        * If we got here, we can now move the vertex from 'from' to 'to' 
+        * If we got here, we can now move the vertex from 'from' to 'to'
         *======================================================================*/
         INC_DEC(pwgts[to], pwgts[from], vwgt);
         graph->mincut -= myedegrees[k].ed-myrinfo->id;
         graph->minvol -= (xgain+myedegrees[k].gv);
         where[i] = to;
 
-        IFSET(ctrl->dbglvl, DBG_MOVEINFO, printf("\t\tMoving %6d from %3d to %3d. Gain: [%4d %4d]. Cut: %6d, Vol: %6d\n", 
+        IFSET(ctrl->dbglvl, DBG_MOVEINFO, printf("\t\tMoving %6d from %3d to %3d. Gain: [%4d %4d]. Cut: %6d, Vol: %6d\n",
               i, from, to, xgain+myedegrees[k].gv, myedegrees[k].ed-myrinfo->id, graph->mincut, graph->minvol));
 
         /* Update pmat to reflect the move of 'i' */
@@ -379,7 +379,7 @@ void Random_KWayVolRefineMConn(CtrlType *ctrl, GraphType *graph, int nparts, flo
     IFSET(ctrl->dbglvl, DBG_REFINE,
        printf("\t[%6d %6d], Balance: %5.3f, Nb: %6d. Nmoves: %5d, Cut: %6d, Vol: %6d\n",
                pwgts[idxamin(nparts, pwgts)], pwgts[idxamax(nparts, pwgts)],
-               1.0*nparts*pwgts[idxamax(nparts, pwgts)]/tvwgt, graph->nbnd, nmoves, graph->mincut, 
+               1.0*nparts*pwgts[idxamax(nparts, pwgts)]/tvwgt, graph->nbnd, nmoves, graph->mincut,
                graph->minvol));
 
     if (graph->minvol == oldvol && graph->mincut == oldcut)
@@ -401,16 +401,16 @@ void Random_KWayVolRefineMConn(CtrlType *ctrl, GraphType *graph, int nparts, flo
 /*************************************************************************
 * This function performs k-way refinement
 **************************************************************************/
-void Greedy_KWayVolBalance(CtrlType *ctrl, GraphType *graph, int nparts, float *tpwgts, 
+void Greedy_KWayVolBalance(CtrlType *ctrl, GraphType *graph, int nparts, float *tpwgts,
                            float ubfactor, int npasses)
 {
   int i, ii/* , iii */, j/* , jj */, k/* , kk, l, u */, pass, nvtxs,
-      nmoves, tvwgt, myndegrees, xgain; 
+      nmoves, tvwgt, myndegrees, xgain;
   int from/* , me */, to, vwgt/* , gain */;
   idxtype *xadj, *adjncy, *adjwgt;
   idxtype *where, *pwgts, *perm, *moved, *bndptr, *bndind, *minwgt, *maxwgt, *itpwgts, *updind, *marker, *phtable;
   VEDegreeType *myedegrees;
-  VRInfoType *myrinfo; 
+  VRInfoType *myrinfo;
   PQueueType queue;
 
   nvtxs = graph->nvtxs;
@@ -423,7 +423,7 @@ void Greedy_KWayVolBalance(CtrlType *ctrl, GraphType *graph, int nparts, float *
 
   where = graph->where;
   pwgts = graph->pwgts;
-  
+
   /* Setup the weight intervals of the various subdomains */
   minwgt =  idxwspacemalloc(ctrl, nparts);
   maxwgt = idxwspacemalloc(ctrl, nparts);
@@ -448,7 +448,7 @@ void Greedy_KWayVolBalance(CtrlType *ctrl, GraphType *graph, int nparts, float *
 
   IFSET(ctrl->dbglvl, DBG_REFINE,
      printf("VolPart: [%5d %5d]-[%5d %5d], Balance: %3.2f, Nv-Nb[%5d %5d]. Cut: %5d, Vol: %5d [B]\n",
-             pwgts[idxamin(nparts, pwgts)], pwgts[idxamax(nparts, pwgts)], minwgt[0], maxwgt[0], 
+             pwgts[idxamin(nparts, pwgts)], pwgts[idxamax(nparts, pwgts)], minwgt[0], maxwgt[0],
              1.0*nparts*pwgts[idxamax(nparts, pwgts)]/tvwgt, graph->nvtxs, graph->nbnd,
              graph->mincut, graph->minvol));
 
@@ -474,7 +474,7 @@ void Greedy_KWayVolBalance(CtrlType *ctrl, GraphType *graph, int nparts, float *
     }
 
     for (nmoves=0;;) {
-      if ((i = PQueueGetMax(&queue)) == -1) 
+      if ((i = PQueueGetMax(&queue)) == -1)
         break;
       moved[i] = 1;
 
@@ -482,7 +482,7 @@ void Greedy_KWayVolBalance(CtrlType *ctrl, GraphType *graph, int nparts, float *
       from = where[i];
       vwgt = graph->vwgt[i];
 
-      if (pwgts[from]-vwgt < minwgt[from]) 
+      if (pwgts[from]-vwgt < minwgt[from])
         continue;   /* This cannot be moved! */
 
       xgain = (myrinfo->id == 0 && myrinfo->ed > 0 ? graph->vsize[i] : 0);
@@ -492,8 +492,8 @@ void Greedy_KWayVolBalance(CtrlType *ctrl, GraphType *graph, int nparts, float *
 
       for (k=0; k<myndegrees; k++) {
         to = myedegrees[k].pid;
-        if (pwgts[to]+vwgt <= maxwgt[to] || 
-            itpwgts[from]*(pwgts[to]+vwgt) <= itpwgts[to]*pwgts[from]) 
+        if (pwgts[to]+vwgt <= maxwgt[to] ||
+            itpwgts[from]*(pwgts[to]+vwgt) <= itpwgts[to]*pwgts[from])
           break;
       }
       if (k == myndegrees)
@@ -501,28 +501,28 @@ void Greedy_KWayVolBalance(CtrlType *ctrl, GraphType *graph, int nparts, float *
 
       for (j=k+1; j<myndegrees; j++) {
         to = myedegrees[j].pid;
-        if (itpwgts[myedegrees[k].pid]*pwgts[to] < itpwgts[to]*pwgts[myedegrees[k].pid]) 
+        if (itpwgts[myedegrees[k].pid]*pwgts[to] < itpwgts[to]*pwgts[myedegrees[k].pid])
           k = j;
       }
 
       to = myedegrees[k].pid;
 
-      if (pwgts[from] < maxwgt[from] && pwgts[to] > minwgt[to] && 
-          (xgain+myedegrees[k].gv < 0 || 
+      if (pwgts[from] < maxwgt[from] && pwgts[to] > minwgt[to] &&
+          (xgain+myedegrees[k].gv < 0 ||
            (xgain+myedegrees[k].gv == 0 &&  myedegrees[k].ed-myrinfo->id < 0))
          )
         continue;
-  
+
 
       /*=====================================================================
-      * If we got here, we can now move the vertex from 'from' to 'to' 
+      * If we got here, we can now move the vertex from 'from' to 'to'
       *======================================================================*/
       INC_DEC(pwgts[to], pwgts[from], vwgt);
       graph->mincut -= myedegrees[k].ed-myrinfo->id;
       graph->minvol -= (xgain+myedegrees[k].gv);
       where[i] = to;
 
-      IFSET(ctrl->dbglvl, DBG_MOVEINFO, printf("\t\tMoving %6d from %3d to %3d. Gain: [%4d %4d]. Cut: %6d, Vol: %6d\n", 
+      IFSET(ctrl->dbglvl, DBG_MOVEINFO, printf("\t\tMoving %6d from %3d to %3d. Gain: [%4d %4d]. Cut: %6d, Vol: %6d\n",
             i, from, to, xgain+myedegrees[k].gv, myedegrees[k].ed-myrinfo->id, graph->mincut, graph->minvol));
 
       KWayVolUpdate(ctrl, graph, i, from, to, marker, phtable, updind);
@@ -535,7 +535,7 @@ void Greedy_KWayVolBalance(CtrlType *ctrl, GraphType *graph, int nparts, float *
     IFSET(ctrl->dbglvl, DBG_REFINE,
        printf("\t[%6d %6d], Balance: %5.3f, Nb: %6d. Nmoves: %5d, Cut: %6d, Vol: %6d\n",
                pwgts[idxamin(nparts, pwgts)], pwgts[idxamax(nparts, pwgts)],
-               1.0*nparts*pwgts[idxamax(nparts, pwgts)]/tvwgt, graph->nbnd, nmoves, graph->mincut, 
+               1.0*nparts*pwgts[idxamax(nparts, pwgts)]/tvwgt, graph->nbnd, nmoves, graph->mincut,
                graph->minvol));
 
   }
@@ -560,13 +560,13 @@ void Greedy_KWayVolBalanceMConn(CtrlType *ctrl, GraphType *graph, int nparts,
 				float *tpwgts, float ubfactor, int npasses)
 {
   int i, ii/* , iii */, j/* , jj */, k/* , kk */, l/* , u */, pass, nvtxs,
-      nmoves, tvwgt, myndegrees, xgain; 
+      nmoves, tvwgt, myndegrees, xgain;
   int from, me, to, vwgt/* , gain */, maxndoms, nadd;
   idxtype *xadj, *adjncy, *adjwgt;
   idxtype *where, *pwgts, *perm, *moved, *bndptr, *bndind, *minwgt, *maxwgt, *itpwgts, *updind, *marker, *phtable;
   idxtype *pmat, *pmatptr, *ndoms;
   VEDegreeType *myedegrees;
-  VRInfoType *myrinfo; 
+  VRInfoType *myrinfo;
   PQueueType queue;
 
   nvtxs = graph->nvtxs;
@@ -579,7 +579,7 @@ void Greedy_KWayVolBalanceMConn(CtrlType *ctrl, GraphType *graph, int nparts,
 
   where = graph->where;
   pwgts = graph->pwgts;
-  
+
   /* Setup the weight intervals of the various subdomains */
   minwgt =  idxwspacemalloc(ctrl, nparts);
   maxwgt = idxwspacemalloc(ctrl, nparts);
@@ -609,7 +609,7 @@ void Greedy_KWayVolBalanceMConn(CtrlType *ctrl, GraphType *graph, int nparts,
 
   IFSET(ctrl->dbglvl, DBG_REFINE,
      printf("VolPart: [%5d %5d]-[%5d %5d], Balance: %3.2f, Nv-Nb[%5d %5d]. Cut: %5d, Vol: %5d [B]\n",
-             pwgts[idxamin(nparts, pwgts)], pwgts[idxamax(nparts, pwgts)], minwgt[0], maxwgt[0], 
+             pwgts[idxamin(nparts, pwgts)], pwgts[idxamax(nparts, pwgts)], minwgt[0], maxwgt[0],
              1.0*nparts*pwgts[idxamax(nparts, pwgts)]/tvwgt, graph->nvtxs, graph->nbnd,
              graph->mincut, graph->minvol));
 
@@ -637,7 +637,7 @@ void Greedy_KWayVolBalanceMConn(CtrlType *ctrl, GraphType *graph, int nparts,
     maxndoms = ndoms[idxamax(nparts, ndoms)];
 
     for (nmoves=0;;) {
-      if ((i = PQueueGetMax(&queue)) == -1) 
+      if ((i = PQueueGetMax(&queue)) == -1)
         break;
       moved[i] = 1;
 
@@ -645,7 +645,7 @@ void Greedy_KWayVolBalanceMConn(CtrlType *ctrl, GraphType *graph, int nparts,
       from = where[i];
       vwgt = graph->vwgt[i];
 
-      if (pwgts[from]-vwgt < minwgt[from]) 
+      if (pwgts[from]-vwgt < minwgt[from])
         continue;   /* This cannot be moved! */
 
       xgain = (myrinfo->id == 0 && myrinfo->ed > 0 ? graph->vsize[i] : 0);
@@ -680,8 +680,8 @@ void Greedy_KWayVolBalanceMConn(CtrlType *ctrl, GraphType *graph, int nparts,
         to = myedegrees[k].pid;
         if (!phtable[to])
           continue;
-        if (pwgts[to]+vwgt <= maxwgt[to] || 
-            itpwgts[from]*(pwgts[to]+vwgt) <= itpwgts[to]*pwgts[from]) 
+        if (pwgts[to]+vwgt <= maxwgt[to] ||
+            itpwgts[from]*(pwgts[to]+vwgt) <= itpwgts[to]*pwgts[from])
           break;
       }
       if (k == myndegrees)
@@ -691,31 +691,31 @@ void Greedy_KWayVolBalanceMConn(CtrlType *ctrl, GraphType *graph, int nparts,
         to = myedegrees[j].pid;
         if (!phtable[to])
           continue;
-        if (itpwgts[myedegrees[k].pid]*pwgts[to] < itpwgts[to]*pwgts[myedegrees[k].pid]) 
+        if (itpwgts[myedegrees[k].pid]*pwgts[to] < itpwgts[to]*pwgts[myedegrees[k].pid])
           k = j;
       }
 
       to = myedegrees[k].pid;
 
-      for (j=0; j<myndegrees; j++) 
+      for (j=0; j<myndegrees; j++)
         phtable[myedegrees[j].pid] = -1;
 
-      if (pwgts[from] < maxwgt[from] && pwgts[to] > minwgt[to] && 
-          (xgain+myedegrees[k].gv < 0 || 
+      if (pwgts[from] < maxwgt[from] && pwgts[to] > minwgt[to] &&
+          (xgain+myedegrees[k].gv < 0 ||
            (xgain+myedegrees[k].gv == 0 &&  myedegrees[k].ed-myrinfo->id < 0))
          )
         continue;
-  
+
 
       /*=====================================================================
-      * If we got here, we can now move the vertex from 'from' to 'to' 
+      * If we got here, we can now move the vertex from 'from' to 'to'
       *======================================================================*/
       INC_DEC(pwgts[to], pwgts[from], vwgt);
       graph->mincut -= myedegrees[k].ed-myrinfo->id;
       graph->minvol -= (xgain+myedegrees[k].gv);
       where[i] = to;
 
-      IFSET(ctrl->dbglvl, DBG_MOVEINFO, printf("\t\tMoving %6d from %3d to %3d. Gain: [%4d %4d]. Cut: %6d, Vol: %6d\n", 
+      IFSET(ctrl->dbglvl, DBG_MOVEINFO, printf("\t\tMoving %6d from %3d to %3d. Gain: [%4d %4d]. Cut: %6d, Vol: %6d\n",
             i, from, to, xgain+myedegrees[k].gv, myedegrees[k].ed-myrinfo->id, graph->mincut, graph->minvol));
 
       /* Update pmat to reflect the move of 'i' */
@@ -780,7 +780,7 @@ void Greedy_KWayVolBalanceMConn(CtrlType *ctrl, GraphType *graph, int nparts,
     IFSET(ctrl->dbglvl, DBG_REFINE,
        printf("\t[%6d %6d], Balance: %5.3f, Nb: %6d. Nmoves: %5d, Cut: %6d, Vol: %6d\n",
                pwgts[idxamin(nparts, pwgts)], pwgts[idxamax(nparts, pwgts)],
-               1.0*nparts*pwgts[idxamax(nparts, pwgts)]/tvwgt, graph->nbnd, nmoves, graph->mincut, 
+               1.0*nparts*pwgts[idxamax(nparts, pwgts)]/tvwgt, graph->nbnd, nmoves, graph->mincut,
                graph->minvol));
 
   }
@@ -809,7 +809,7 @@ void Greedy_KWayVolBalanceMConn(CtrlType *ctrl, GraphType *graph, int nparts,
 void KWayVolUpdate(CtrlType *ctrl, GraphType *graph, int v, int from, int to,
                    idxtype *marker, idxtype *phtable, idxtype *updind)
 {
-  int ii/* , iii */, j, jj, k, kk/* , l */, u, nupd, other, me, myidx; 
+  int ii/* , iii */, j, jj, k, kk/* , l */, u, nupd, other, me, myidx;
   idxtype *xadj, *vsize, *adjncy, *adjwgt, *where;
   VEDegreeType *myedegrees, *oedegrees;
   VRInfoType *myrinfo, *orinfo;
@@ -825,7 +825,7 @@ void KWayVolUpdate(CtrlType *ctrl, GraphType *graph, int v, int from, int to,
 
 
   /*======================================================================
-   * Remove the contributions on the gain made by 'v'. 
+   * Remove the contributions on the gain made by 'v'.
    *=====================================================================*/
   for (k=0; k<myrinfo->ndegrees; k++)
     phtable[myedegrees[k].pid] = k;
@@ -841,7 +841,7 @@ void KWayVolUpdate(CtrlType *ctrl, GraphType *graph, int v, int from, int to,
 
     if (other == from) {
       for (k=0; k<orinfo->ndegrees; k++) {
-        if (phtable[oedegrees[k].pid] == -1) 
+        if (phtable[oedegrees[k].pid] == -1)
           oedegrees[k].gv += vsize[v];
       }
     }
@@ -850,13 +850,13 @@ void KWayVolUpdate(CtrlType *ctrl, GraphType *graph, int v, int from, int to,
 
       if (myedegrees[phtable[other]].ned > 1) {
         for (k=0; k<orinfo->ndegrees; k++) {
-          if (phtable[oedegrees[k].pid] == -1) 
+          if (phtable[oedegrees[k].pid] == -1)
             oedegrees[k].gv += vsize[v];
         }
       }
       else { /* There is only one connection */
         for (k=0; k<orinfo->ndegrees; k++) {
-          if (phtable[oedegrees[k].pid] != -1) 
+          if (phtable[oedegrees[k].pid] != -1)
             oedegrees[k].gv -= vsize[v];
         }
       }
@@ -874,7 +874,7 @@ void KWayVolUpdate(CtrlType *ctrl, GraphType *graph, int v, int from, int to,
   myrinfo->ed += myrinfo->id-myedegrees[myidx].ed;
   SWAP(myrinfo->id, myedegrees[myidx].ed, j);
   SWAP(myrinfo->nid, myedegrees[myidx].ned, j);
-  if (myedegrees[myidx].ed == 0) 
+  if (myedegrees[myidx].ed == 0)
     myedegrees[myidx] = myedegrees[--myrinfo->ndegrees];
   else
     myedegrees[myidx].pid = from;
@@ -904,7 +904,7 @@ void KWayVolUpdate(CtrlType *ctrl, GraphType *graph, int v, int from, int to,
     if (me == from) {
       INC_DEC(myrinfo->ed, myrinfo->id, adjwgt[j]);
       myrinfo->nid--;
-    } 
+    }
     else if (me == to) {
       INC_DEC(myrinfo->id, myrinfo->ed, adjwgt[j]);
       myrinfo->nid++;
@@ -947,15 +947,15 @@ void KWayVolUpdate(CtrlType *ctrl, GraphType *graph, int v, int from, int to,
                 oedegrees = orinfo->edegrees;
 
                 if (other == from) {
-                  for (kk=0; kk<orinfo->ndegrees; kk++) 
+                  for (kk=0; kk<orinfo->ndegrees; kk++)
                     oedegrees[kk].gv += vsize[ii];
-                  break;  
+                  break;
                 }
               }
             }
           }
 
-          break; 
+          break;
         }
       }
     }
@@ -977,9 +977,9 @@ void KWayVolUpdate(CtrlType *ctrl, GraphType *graph, int v, int from, int to,
               oedegrees = orinfo->edegrees;
 
               if (u != v && other == to) {
-                for (kk=0; kk<orinfo->ndegrees; kk++) 
+                for (kk=0; kk<orinfo->ndegrees; kk++)
                   oedegrees[kk].gv -= vsize[ii];
-                break;  
+                break;
               }
             }
           }
@@ -1034,7 +1034,7 @@ void KWayVolUpdate(CtrlType *ctrl, GraphType *graph, int v, int from, int to,
 
     if (other == to) {
       for (k=0; k<orinfo->ndegrees; k++) {
-        if (phtable[oedegrees[k].pid] == -1) 
+        if (phtable[oedegrees[k].pid] == -1)
           oedegrees[k].gv -= vsize[v];
       }
     }
@@ -1043,13 +1043,13 @@ void KWayVolUpdate(CtrlType *ctrl, GraphType *graph, int v, int from, int to,
 
       if (myedegrees[phtable[other]].ned > 1) {
         for (k=0; k<orinfo->ndegrees; k++) {
-          if (phtable[oedegrees[k].pid] == -1) 
+          if (phtable[oedegrees[k].pid] == -1)
             oedegrees[k].gv -= vsize[v];
         }
       }
       else { /* There is only one connection */
         for (k=0; k<orinfo->ndegrees; k++) {
-          if (phtable[oedegrees[k].pid] != -1) 
+          if (phtable[oedegrees[k].pid] != -1)
             oedegrees[k].gv += vsize[v];
         }
       }
@@ -1088,7 +1088,7 @@ void KWayVolUpdate(CtrlType *ctrl, GraphType *graph, int v, int from, int to,
 
 
 /*************************************************************************
-* This function computes the initial id/ed 
+* This function computes the initial id/ed
 **************************************************************************/
 void ComputeKWayVolume(GraphType *graph, int nupd, idxtype *updind,
 		       idxtype *marker, idxtype *phtable)
@@ -1118,7 +1118,7 @@ void ComputeKWayVolume(GraphType *graph, int nupd, idxtype *updind,
     myedegrees = myrinfo->edegrees;
 
     if (marker[i] == 1) {  /* Only complete gain updates go through */
-      for (k=0; k<myrinfo->ndegrees; k++) 
+      for (k=0; k<myrinfo->ndegrees; k++)
         myedegrees[k].gv = 0;
 
       for (j=xadj[i]; j<xadj[i+1]; j++) {
@@ -1127,7 +1127,7 @@ void ComputeKWayVolume(GraphType *graph, int nupd, idxtype *updind,
         orinfo = rinfo+ii;
         oedegrees = orinfo->edegrees;
 
-        for (kk=0; kk<orinfo->ndegrees; kk++) 
+        for (kk=0; kk<orinfo->ndegrees; kk++)
           phtable[oedegrees[kk].pid] = kk;
         phtable[other] = 1;
 
@@ -1142,26 +1142,26 @@ void ComputeKWayVolume(GraphType *graph, int nupd, idxtype *updind,
           ASSERT(phtable[me] != -1);
 
           /* I'm the only connection of 'ii' in 'me' */
-          if (oedegrees[phtable[me]].ned == 1) { 
+          if (oedegrees[phtable[me]].ned == 1) {
             /* Increase the gains for all the common domains between 'i' and 'ii' */
             for (k=0; k<myrinfo->ndegrees; k++) {
-              if (phtable[myedegrees[k].pid] != -1) 
+              if (phtable[myedegrees[k].pid] != -1)
                 myedegrees[k].gv += vsize[ii];
             }
           }
           else {
             /* Find which domains 'i' is connected and 'ii' is not and update their gain */
             for (k=0; k<myrinfo->ndegrees; k++) {
-              if (phtable[myedegrees[k].pid] == -1) 
+              if (phtable[myedegrees[k].pid] == -1)
                 myedegrees[k].gv -= vsize[ii];
             }
           }
         }
 
-        for (kk=0; kk<orinfo->ndegrees; kk++) 
+        for (kk=0; kk<orinfo->ndegrees; kk++)
           phtable[oedegrees[kk].pid] = -1;
         phtable[other] = -1;
-  
+
       }
     }
 
@@ -1219,7 +1219,7 @@ int ComputeVolume(GraphType *graph, idxtype *where)
 
 
 /*************************************************************************
-* This function computes the initial id/ed 
+* This function computes the initial id/ed
 **************************************************************************/
 void CheckVolKWayPartitionParams(CtrlType *ctrl, GraphType *graph, int nparts)
 {
@@ -1275,7 +1275,7 @@ void CheckVolKWayPartitionParams(CtrlType *ctrl, GraphType *graph, int nparts)
             if (oedegrees[kk].pid == pid)
               break;
           }
-          if (kk == orinfo->ndegrees) 
+          if (kk == orinfo->ndegrees)
             myedegrees[k].gv -= vsize[ii];
         }
       }
@@ -1316,7 +1316,7 @@ void CheckVolKWayPartitionParams(CtrlType *ctrl, GraphType *graph, int nparts)
               if (oedegrees[kk].pid == pid)
                 break;
             }
-            if (kk == orinfo->ndegrees) 
+            if (kk == orinfo->ndegrees)
               myedegrees[k].gv -= vsize[ii];
           }
         }
@@ -1370,7 +1370,7 @@ void ComputeVolSubDomainGraph(GraphType *graph, int nparts, idxtype *pmat, idxty
       edegrees = rinfo[i].edegrees;
 
       k = me*nparts;
-      for (j=0; j<ndegrees; j++) 
+      for (j=0; j<ndegrees; j++)
         pmat[k+edegrees[j].pid] += edegrees[j].ed;
     }
   }
@@ -1420,7 +1420,7 @@ void EliminateVolSubDomainEdges(CtrlType *ctrl, GraphType *graph, int nparts, fl
     pwgts[me] += vwgt[i];
     for (j=xadj[i]; j<xadj[i+1]; j++) {
       k = adjncy[j];
-      if (where[k] != me) 
+      if (where[k] != me)
         pmat[me*nparts+where[k]] += adjwgt[j];
     }
   }
@@ -1467,7 +1467,7 @@ void EliminateVolSubDomainEdges(CtrlType *ctrl, GraphType *graph, int nparts, fl
 
     move = 0;
     for (min=0; min<ncand2; min++) {
-      if (cand2[min].key > totalout/(2*ndoms[me])) 
+      if (cand2[min].key > totalout/(2*ndoms[me]))
         break;
 
       other = cand2[min].val;
@@ -1495,7 +1495,7 @@ void EliminateVolSubDomainEdges(CtrlType *ctrl, GraphType *graph, int nparts, fl
 
         for (j=xadj[i]; j<xadj[i+1]; j++) {
           k = adjncy[j];
-          if (where[k] != other) 
+          if (where[k] != other)
             otherpmat[where[k]] += adjwgt[j];
         }
       }
@@ -1508,7 +1508,7 @@ void EliminateVolSubDomainEdges(CtrlType *ctrl, GraphType *graph, int nparts, fl
       }
       ikeysort(ncand, cand);
 
-      /* 
+      /*
        * Go through and the select the first domain that is common with 'me', and
        * does not increase the ndoms[target] higher than my ndoms, subject to the
        * maxpwgt constraint. Traversal is done from the mostly connected to the least.
@@ -1585,7 +1585,7 @@ void EliminateVolSubDomainEdges(CtrlType *ctrl, GraphType *graph, int nparts, fl
             if (pmat[nparts*target + where[k]] == 0)
               ndoms[target]++;
             pmat[nparts*target + where[k]] += adjwgt[j];
-  
+
             if (pmat[nparts*where[k] + target] == 0)
               ndoms[where[k]]++;
             pmat[nparts*where[k] + target] += adjwgt[j];
@@ -1612,13 +1612,14 @@ void EliminateVolSubDomainEdges(CtrlType *ctrl, GraphType *graph, int nparts, fl
 
 
 /*************************************************************************
-* This function finds all the connected components induced by the 
-* partitioning vector in wgraph->where and tries to push them around to 
+* This function finds all the connected components induced by the
+* partitioning vector in wgraph->where and tries to push them around to
 * remove some of them
 **************************************************************************/
 void EliminateVolComponents(CtrlType *ctrl, GraphType *graph, int nparts, float *tpwgts, float ubfactor)
 {
-  int i, ii, j, jj, k, me, nvtxs, tvwgt, first, last, nleft, ncmps, cwgt, ncand, other, target, deltawgt;
+    int i, ii, j, jj, k, me =-1/*-Wall*/, nvtxs, tvwgt, first, last,
+	nleft, ncmps, cwgt, ncand, other, target, deltawgt;
   idxtype *xadj, *adjncy, *vwgt, *adjwgt, *where, *pwgts, *maxpwgt;
   idxtype *cpvec, *touched, *perm, *todo, *cind, *cptr, *npcmps;
   KeyValueType *cand;
@@ -1642,7 +1643,7 @@ void EliminateVolComponents(CtrlType *ctrl, GraphType *graph, int nparts, float
   cpvec = idxwspacemalloc(ctrl, nparts);
   npcmps = idxset(nparts, 0, idxwspacemalloc(ctrl, nparts));
 
-  for (i=0; i<nvtxs; i++) 
+  for (i=0; i<nvtxs; i++)
     perm[i] = todo[i] = i;
 
   /* Find the connected componends induced by the partition */
@@ -1681,7 +1682,7 @@ void EliminateVolComponents(CtrlType *ctrl, GraphType *graph, int nparts, float
     cand = (KeyValueType *)GKmalloc(nparts*sizeof(KeyValueType), "EliminateSubDomainEdges: cand");
 
     /* First determine the partition sizes and max allowed load imbalance */
-    for (i=0; i<nvtxs; i++) 
+    for (i=0; i<nvtxs; i++)
       pwgts[where[i]] += vwgt[i];
     tvwgt = idxsum(nparts, pwgts);
     for (i=0; i<nparts; i++)
@@ -1742,7 +1743,7 @@ void EliminateVolComponents(CtrlType *ctrl, GraphType *graph, int nparts, float
         pwgts[target] += cwgt;
         npcmps[me]--;
 
-        for (j=cptr[i]; j<cptr[i+1]; j++) 
+        for (j=cptr[i]; j<cptr[i+1]; j++)
           where[cind[j]] = target;
 
         graph->mincut -= cpvec[target];
